@@ -140,3 +140,39 @@ def frozendict(*args, **kwargs):
         list(my_dict.items())  # --> [("a", 1), ("b", 2)]
     """
     return types.MappingProxyType(dict(*args, **kwargs))
+
+
+def from_objects(iterable, key_getter, value_getter):
+    """
+    Create a new dictionary with elements generated from
+    the "key_getter" and "value_getter" callbacks applied to each element of the iterable.
+
+    :param Iterable[any] iterable:
+    :param Callable key_getter:
+        Dictionary keys getter.
+        It is called with each element of "iterable" passing it as an argument.
+    :param Callable value_getter:
+        Dictionary values getter.
+        It is called with each element of "iterable" passing it as an argument.
+
+    :raise: ValueError if any generated key is duplicate.
+    :rtype: dict
+
+    Examples:
+        from pymince.dictionary import from_objects
+
+        keygetter = operator.itemgetter(0)
+        valgetter = operator.itemgetter(1, 2)
+
+        values = iter([(1, "a", "b"), (2, "a", "b")])
+        from_objects(values, keygetter, valgetter) # --> {1: ('a', 'b'), 2: ('a', 'b')}
+    """
+
+    dictionary = {}
+    for obj in iter(iterable):
+        key = key_getter(obj)
+        if key in dictionary:
+            raise ValueError
+        else:
+            dictionary[key] = value_getter(obj)
+    return dictionary
