@@ -10,7 +10,7 @@ def retry_if_none(delay=0, tries=1):
     :param int delay: seconds delay between attempts. default: 0.
     :param int tries: number of attempts. default: 1
 
-    Usage:
+    Examples:
         @retry_if_none(delay=0, tries=1)
         def foo():
             return 1
